@@ -3,6 +3,7 @@
 #
 
 import paho.mqtt.client as mqtt
+import random, string
 
 # MQTT(host=127.0.0.1, port=1883, client_id=[random])
 # 	.on_connect(callback[client, userdata, flags, rc])
@@ -19,27 +20,19 @@ class MQTT():
 		else:
 			self.client_id = str(client_id)
 		
-		log("mqtt", "creating client '{}'".format(self.client_id))
 		self.client = mqtt.Client(client_id=client_id)
-		log("mqtt", "connecting to '{}:{}'".format(str(self.host), str(self.port)))
 		self.client.connect(self.host, self.port)
-		log("mqtt", "starting event loop")
 		self.client.loop_start()
 
 	def on_connect(self, fn):
-		log("mqtt", "adding 'on_connect' callback")
 		self.client.on_connect = fn
 
 	def on_message(self, fn):
-		log("mqtt", "adding 'on_message' callback")
 		self.client.on_message = fn
 
 	def publish(self, topic, payload, disable_log=False):
-		if not disable_log:
-			log("mqtt", "publishing message: {}:{} -> {} -> '{}'".format(str(self.host), str(self.port), str(topic), str(payload)))
 		return self.client.publish(topic, payload)
 
 	def subscribe(self, topic):
-		log("mqtt", "subscribing to {}:{} {}".format(str(self.host), str(self.port), str(topic)))
 		return self.client.subscribe(topic)
 
